# XIBS

This repository contains what became `xibs`, a prototype for Intra-Beam Scattering (IBS) modelling and computing to be later integrated into [xsuite](https://github.com/xsuite).


> [!NOTE]
> This started as a fork of M. Zampetakis' work on a simple but physics-accurate
> [IBS implementation](https://github.com/MichZampetakis/IBS_for_Xsuite). The new
> package's code is quite different from the original but is benchmarked against
> it as well as other tools to ensure the validity of results.

See the [documentation](https://fsoubelet.github.io/xibs/) for details.

## Installing

Installation is easily done in your environment via `pip`:
```bash
python -m pip install xibs
```

## License

This project is licensed under the `Apache-2.0 License` - see the [LICENSE](LICENSE) file for details.